@@ -133,18 +133,16 @@ grouped_ggwithinstats <- function(data,
 
   # creating a dataframe
   df <-
+    data %>%
     dplyr::select(
-      .data = data,
-      !!rlang::enquo(x),
-      !!rlang::enquo(y),
-      !!rlang::enquo(grouping.var),
-      !!rlang::enquo(outlier.label)
+      .data = .,
+      {{ grouping.var }},
+      {{ x }},
+      {{ y }},
+      {{ outlier.label }}
     ) %>%
-    tidyr::drop_na(data = .)
-
-  # creating a list for grouped analysis
-  df %<>%
-    grouped_list(data = ., grouping.var = !!rlang::enquo(grouping.var))
+    tidyr::drop_na(data = .) %>% # creating a list for grouped analysis
+    grouped_list(data = ., grouping.var = {{ grouping.var }})
 
   # ============== build pmap list based on conditions =====================
 
