@@ -1,5 +1,4 @@
-#' @title Convenience function to extract bayes factors from `BayesFactor` model
-#'   object.
+#' @title Extract Bayes Factors from `BayesFactor` model object.
 #' @name bf_extractor
 #'
 #' @param bf.object An object from `BayesFactor` package test results.
@@ -13,7 +12,8 @@
 #' @examples
 #' # getting only bayes factors
 #' ggstatsplot::bf_extractor(
-#'   BayesFactor::anovaBF(Sepal.Length ~ Species,
+#'   BayesFactor::anovaBF(
+#'     formula = Sepal.Length ~ Species,
 #'     data = iris,
 #'     progress = FALSE
 #'   )
@@ -42,16 +42,6 @@ bf_extractor <- function(bf.object,
       log_e_bf01 = log(bf01),
       log_10_bf10 = log10(bf10),
       log_10_bf01 = log10(bf01)
-    ) %>%
-    dplyr::select(
-      .data = .,
-      bf10,
-      log_e_bf10,
-      log_10_bf10,
-      bf01,
-      log_e_bf01,
-      log_10_bf01,
-      dplyr::everything()
     )
 
   # return the dataframe with bayes factors
@@ -123,7 +113,7 @@ bf_caption_maker <- function(bf.df,
 
   # prepare the bayes factor message
   bf_text <-
-    base::substitute(
+    substitute(
       atop(displaystyle(top.text),
         expr =
           paste(
@@ -133,12 +123,12 @@ bf_caption_maker <- function(bf.df,
             ") = ",
             bf,
             ", ",
-            italic("r")["Cauchy"],
+            italic("r")["Cauchy"]^"JZS",
             " = ",
             bf_prior
           )
       ),
-      env = base::list(
+      env = list(
         hypothesis.text = hypothesis.text,
         top.text = caption,
         bf.subscript = bf.subscript,
@@ -161,10 +151,11 @@ bf_caption_maker <- function(bf.df,
 #' @param bf.prior A number between 0.5 and 2 (default `0.707`), the prior width
 #'   to use in calculating Bayes factors.
 #'
-#' @importFrom BayesFactor correlationBF extractBF
+#' @importFrom BayesFactor correlationBF
+#' @importFrom dplyr pull
 #'
 #' @seealso \code{\link{bf_contingency_tab}}, \code{\link{bf_oneway_anova}},
-#' \code{\link{bf_two_sample_ttest}}
+#' \code{\link{bf_ttest}}
 #'
 #' @examples
 #'
@@ -202,12 +193,8 @@ bf_corr_test <- function(data,
   # ============================ data preparation ==========================
 
   # creating a dataframe
-  data <-
-    dplyr::select(
-      .data = data,
-      x = !!rlang::enquo(x),
-      y = !!rlang::enquo(y)
-    ) %>%
+  data %<>%
+    dplyr::select(.data = ., {{ x }}, {{ y }}) %>%
     tidyr::drop_na(data = .) %>%
     tibble::as_tibble(.)
 
@@ -217,8 +204,8 @@ bf_corr_test <- function(data,
   bf_results <-
     bf_extractor(
       BayesFactor::correlationBF(
-        x = data$x,
-        y = data$y,
+        x = data %>% dplyr::pull({{ x }}),
+        y = data %>% dplyr::pull({{ y }}),
         nullInterval = NULL,
         rscale = bf.prior,
         ...
@@ -266,13 +253,21 @@ bf_corr_test <- function(data,
 #'   hypothesis under the alternative, and corresponds to Gunel and Dickey's
 #'   (1974) `"a"` parameter.
 #'
-#' @importFrom BayesFactor contingencyTableBF extractBF
+#' @importFrom BayesFactor contingencyTableBF logMeanExpLogs
+#' @importFrom stats dmultinom
+#' @importFrom MCMCpack rdirichlet
 #'
 #' @seealso \code{\link{bf_corr_test}}, \code{\link{bf_oneway_anova}},
-#' \code{\link{bf_two_sample_ttest}}
+#' \code{\link{bf_ttest}}
+#'
+#' @note Bayes Factor for goodness of fit test is based on gist provided by
+#'   Richard Morey:
+#'   \url{https://gist.github.com/richarddmorey/a4cd3a2051f373db917550d67131dba4}.
 #'
 #' @examples
 #'
+#' # ------------------ association tests --------------------------------
+#'
 #' # for reproducibility
 #' set.seed(123)
 #' library(ggstatsplot)
@@ -303,12 +298,22 @@ bf_corr_test <- function(data,
 #'   fixed.margin = "rows",
 #'   prior.concentration = 1
 #' )
+#'
+#' # ------------------ goodness of fit tests --------------------------------
+#'
+#' bf_contingency_tab(
+#'   data = mtcars,
+#'   main = am,
+#'   prior.concentration = 10
+#' )
 #' @export
 
 # function body
 bf_contingency_tab <- function(data,
                                main,
-                               condition,
+                               condition = NULL,
+                               counts = NULL,
+                               ratio = NULL,
                                sampling.plan = "indepMulti",
                                fixed.margin = "rows",
                                prior.concentration = 1,
@@ -316,52 +321,125 @@ bf_contingency_tab <- function(data,
                                output = "null",
                                k = 2,
                                ...) {
+  ellipsis::check_dots_used()
 
-  # ============================ data preparation ==========================
+  # =============================== dataframe ================================
 
   # creating a dataframe
-  data <-
+  data %<>%
     dplyr::select(
-      .data = data,
-      x = !!rlang::enquo(main),
-      y = !!rlang::enquo(condition)
+      .data = .,
+      main = {{ main }},
+      condition = {{ condition }},
+      counts = {{ counts }}
     ) %>%
     tidyr::drop_na(data = .) %>%
-    dplyr::mutate(
-      .data = .,
-      x = droplevels(as.factor(x)), y = droplevels(as.factor(y))
-    ) %>%
-    tibble::as_tibble(.)
+    tibble::as_tibble(x = .)
 
-  # ========================= subtitle preparation ==========================
+  # =========================== converting counts ============================
 
-  # detailed text of sample plan
-  sampling_plan_text <-
-    switch(
-      EXPR = sampling.plan,
-      "jointMulti" = "joint multinomial",
-      "poisson" = "poisson",
-      "indepMulti" = "independent multinomial",
-      "hypergeom" = "hypergeometric"
-    )
-
-  # extracting results from bayesian test and creating a dataframe
-  bf_results <-
-    bf_extractor(
-      BayesFactor::contingencyTableBF(
-        x = table(data$x, data$y),
-        sampleType = sampling.plan,
-        fixedMargin = fixed.margin,
-        priorConcentration = prior.concentration,
-        ...
+  # untable the dataframe based on the count for each obervation
+  if ("counts" %in% names(data)) {
+    data %<>%
+      tidyr::uncount(
+        data = .,
+        weights = counts,
+        .remove = TRUE,
+        .id = "id"
       )
-    ) %>%
-    dplyr::mutate(
-      .data = .,
-      sampling.plan = sampling_plan_text,
-      fixed.margin = fixed.margin,
-      prior.concentration = prior.concentration
-    )
+  }
+
+  # main and condition need to be a factor for this analysis
+  # also drop the unused levels of the factors
+
+  # main
+  data %<>%
+    dplyr::mutate(.data = ., main = droplevels(as.factor(main)))
+
+  # ratio
+  if (is.null(ratio)) {
+    ratio <- rep(1 / length(table(data$main)), length(table(data$main)))
+  }
+
+  # ========================= caption preparation ==========================
+
+  if ("condition" %in% names(data)) {
+
+    # dropping unused levels
+    data %<>%
+      dplyr::mutate(.data = ., condition = droplevels(as.factor(condition)))
+
+    # detailed text of sample plan
+    sampling_plan_text <-
+      switch(
+        EXPR = sampling.plan,
+        "jointMulti" = "joint multinomial",
+        "poisson" = "poisson",
+        "indepMulti" = "independent multinomial",
+        "hypergeom" = "hypergeometric"
+      )
+
+    # extracting results from bayesian test and creating a dataframe
+    bf_results <-
+      bf_extractor(
+        BayesFactor::contingencyTableBF(
+          x = table(data$main, data$condition),
+          sampleType = sampling.plan,
+          fixedMargin = fixed.margin,
+          priorConcentration = prior.concentration,
+          ...
+        )
+      ) %>%
+      dplyr::mutate(
+        .data = .,
+        sampling.plan = sampling_plan_text,
+        fixed.margin = fixed.margin,
+        prior.concentration = prior.concentration
+      )
+  } else {
+    # no. of levels in `main` variable
+    n_levels <- length(as.vector(table(data$main)))
+
+    if (1 / n_levels == 0 || 1 / n_levels == 1) {
+      return(NULL)
+    }
+
+    # one sample goodness of fit test for equal proportions
+    y <- as.matrix(table(data$main))
+
+    # (log) prob of data under null
+    pr_y_h0 <- stats::dmultinom(x = y, prob = ratio, log = TRUE)
+
+    # estimate log prob of data under null with Monte Carlo
+    M <- 100000
+    p1s <- MCMCpack::rdirichlet(n = M, alpha = prior.concentration * ratio)
+    tmp_pr_h1 <-
+      sapply(
+        X = 1:M,
+        FUN = function(i)
+          stats::dmultinom(x = y, prob = p1s[i, ], log = TRUE)
+      )
+
+    # estimate log prob of data under alternative
+    pr_y_h1 <- BayesFactor::logMeanExpLogs(v = tmp_pr_h1)
+
+    # computing Bayes Factor
+    bf_10 <- exp(pr_y_h1 - pr_y_h0)
+
+    # dataframe with results
+    bf_results <-
+      tibble::enframe(bf_10) %>%
+      dplyr::select(.data = ., bf10 = value) %>%
+      dplyr::mutate(
+        .data = .,
+        bf01 = 1 / bf10,
+        log_e_bf10 = log(bf10),
+        log_e_bf01 = log(bf01),
+        log_10_bf10 = log10(bf10),
+        log_10_bf01 = log10(bf01)
+      ) %>%
+      dplyr::mutate(.data = ., prior.concentration = prior.concentration)
+  }
 
   # changing aspects of the caption based on what output is needed
   if (output %in% c("null", "caption", "H0", "h0")) {
@@ -374,35 +452,63 @@ bf_contingency_tab <- function(data,
     bf.subscript <- "10"
   }
 
-  # prepare the bayes factor message
-  bf_message <-
-    base::substitute(
-      atop(
-        displaystyle(top.text),
-        expr =
-          paste(
-            hypothesis.text,
-            "log"["e"],
-            "(BF"[bf.subscript],
-            ") = ",
-            bf,
-            ", sampling = ",
-            sampling.plan,
-            ", ",
-            italic("a"),
-            " = ",
-            a
-          )
-      ),
-      env = base::list(
-        hypothesis.text = hypothesis.text,
-        top.text = caption,
-        bf.subscript = bf.subscript,
-        bf = specify_decimal_p(x = bf.value, k = k),
-        sampling.plan = sampling_plan_text,
-        a = specify_decimal_p(x = bf_results$prior.concentration[[1]], k = k)
+  # prepare the Bayes Factor message
+  if ("condition" %in% names(data)) {
+    bf_message <-
+      substitute(
+        atop(
+          displaystyle(top.text),
+          expr =
+            paste(
+              hypothesis.text,
+              "log"["e"],
+              "(BF"[bf.subscript],
+              ") = ",
+              bf,
+              ", sampling = ",
+              sampling.plan,
+              ", ",
+              italic("a"),
+              " = ",
+              a
+            )
+        ),
+        env = list(
+          hypothesis.text = hypothesis.text,
+          top.text = caption,
+          bf.subscript = bf.subscript,
+          bf = specify_decimal_p(x = bf.value, k = k),
+          sampling.plan = sampling_plan_text,
+          a = specify_decimal_p(x = bf_results$prior.concentration[[1]], k = k)
+        )
       )
-    )
+  } else {
+    bf_message <-
+      substitute(
+        atop(
+          displaystyle(top.text),
+          expr =
+            paste(
+              hypothesis.text,
+              "log"["e"],
+              "(BF"[bf.subscript],
+              ") = ",
+              bf,
+              ", ",
+              italic("a"),
+              " = ",
+              a
+            )
+        ),
+        env = list(
+          hypothesis.text = hypothesis.text,
+          top.text = caption,
+          bf.subscript = bf.subscript,
+          bf = specify_decimal_p(x = bf.value, k = k),
+          a = specify_decimal_p(x = bf_results$prior.concentration[[1]], k = k)
+        )
+      )
+  }
 
   # ============================ return ==================================
 
@@ -414,27 +520,32 @@ bf_contingency_tab <- function(data,
   ))
 }
 
-
-#' @title Bayesian two-samples *t*-test.
-#' @name bf_two_sample_ttest
+#' @title Bayes Factor for *t*-test
 #' @author Indrajeet Patil
+#' @details If `y` is `NULL`, a one-sample *t*-test will be carried out,
+#'   otherwise a two-sample *t*-test will be carried out.
 #'
-#' @importFrom BayesFactor ttestBF extractBF
+#' @importFrom BayesFactor ttestBF
 #'
-#' @inheritParams BayesFactor::ttestBF
+#' @param x Either the grouping variable from the dataframe `data` if it's a
+#'   two-sample *t*-test or a numeric variable if it's a one-sample *t*-test.
 #' @inheritParams ggbetweenstats
+#' @inheritParams BayesFactor::ttestBF
 #' @inheritParams bf_corr_test
+#' @inheritParams subtitle_t_onesample
 #'
 #' @seealso \code{\link{bf_contingency_tab}}, \code{\link{bf_corr_test}},
 #' \code{\link{bf_oneway_anova}}
 #'
 #' @examples
 #'
+#' # ------------------- two-samples tests -----------------------------------
+#'
 #' # for reproducibility
 #' set.seed(123)
 #'
 #' # to get caption (default)
-#' bf_two_sample_ttest(
+#' bf_ttest(
 #'   data = mtcars,
 #'   x = am,
 #'   y = wt,
@@ -443,7 +554,7 @@ bf_contingency_tab <- function(data,
 #' )
 #'
 #' # to see results
-#' bf_two_sample_ttest(
+#' bf_ttest(
 #'   data = mtcars,
 #'   x = am,
 #'   y = wt,
@@ -452,7 +563,7 @@ bf_contingency_tab <- function(data,
 #' )
 #'
 #' # for paired sample test
-#' bf_two_sample_ttest(
+#' bf_ttest(
 #'   data = dplyr::filter(
 #'     ggstatsplot::intent_morality,
 #'     condition %in% c("accidental", "attempted"),
@@ -463,18 +574,39 @@ bf_contingency_tab <- function(data,
 #'   paired = TRUE,
 #'   output = "results"
 #' )
+#'
+#' # ------------------- one-samples test -----------------------------------
+#'
+#' # to get caption (default)
+#' bf_ttest(
+#'   data = iris,
+#'   x = Sepal.Length,
+#'   test.value = 5.85,
+#'   bf.prior = 0.8,
+#'   output = "caption", k = 2
+#' )
+#'
+#' # to get results dataframe
+#' bf_ttest(
+#'   data = iris,
+#'   x = Sepal.Length,
+#'   test.value = 5.85,
+#'   bf.prior = 0.8,
+#'   output = "results"
+#' )
 #' @export
 
 # function body
-bf_two_sample_ttest <- function(data,
-                                x,
-                                y,
-                                paired = FALSE,
-                                bf.prior = 0.707,
-                                caption = NULL,
-                                output = "null",
-                                k = 2,
-                                ...) {
+bf_ttest <- function(data,
+                     x,
+                     y = NULL,
+                     test.value = 0,
+                     paired = FALSE,
+                     bf.prior = 0.707,
+                     caption = NULL,
+                     output = "null",
+                     k = 2,
+                     ...) {
 
   # ============================ data preparation ==========================
 
@@ -485,57 +617,72 @@ bf_two_sample_ttest <- function(data,
       x = !!rlang::enquo(x),
       y = !!rlang::enquo(y)
     ) %>%
-    dplyr::mutate(.data = ., x = droplevels(as.factor(x))) %>%
     tibble::as_tibble(.)
 
   # -------------------------- between-subjects design -------------------
 
-  # running bayesian analysis
-  if (!isTRUE(paired)) {
+  if ("y" %in% names(data)) {
 
-    # removing NAs
+    # dropping unused factor levels from `x` variable
     data %<>%
-      stats::na.omit(.)
+      dplyr::mutate(.data = ., x = droplevels(as.factor(x)))
 
-    # extracting results from bayesian test and creating a dataframe
+    # running bayesian analysis
+    if (!isTRUE(paired)) {
+
+      # removing NAs
+      data %<>% tidyr::drop_na(.)
+
+      # extracting results from bayesian test and creating a dataframe
+      bf_object <-
+        BayesFactor::ttestBF(
+          formula = y ~ x,
+          data = as.data.frame(data),
+          rscale = bf.prior,
+          paired = FALSE,
+          progress = FALSE,
+          ...
+        )
+    } else {
+      # the data needs to be in wide format
+      data_wide <-
+        long_to_wide_converter(
+          data = data,
+          x = x,
+          y = y
+        )
+
+      # change names for convenience
+      colnames(data_wide) <- c("rowid", "col1", "col2")
+
+      # extracting results from Bayesian test and creating a dataframe
+      bf_object <-
+        BayesFactor::ttestBF(
+          x = data_wide$col1,
+          y = data_wide$col2,
+          rscale = bf.prior,
+          paired = TRUE,
+          progress = FALSE,
+          ...
+        )
+    }
+  } else {
     bf_object <-
       BayesFactor::ttestBF(
-        formula = y ~ x,
-        data = as.data.frame(data),
+        x = data$x,
         rscale = bf.prior,
-        paired = FALSE,
-        progress = FALSE,
-        ...
-      )
-  } else if (isTRUE(paired)) {
-    # the data needs to be in wide format
-    data_wide <-
-      long_to_wide_converter(
-        data = data,
-        x = x,
-        y = y
-      )
-
-    # change names for convenience
-    colnames(data_wide) <- c("rowid", "col1", "col2")
-
-    # extracting results from bayesian test and creating a dataframe
-    bf_object <-
-      BayesFactor::ttestBF(
-        x = data_wide$col1,
-        y = data_wide$col2,
-        rscale = bf.prior,
-        paired = TRUE,
-        progress = FALSE,
+        mu = test.value,
+        nullInterval = NULL,
         ...
       )
   }
 
-  # extracting the bayes factors
-  bf_results <- bf_extractor(bf.object = bf_object) %>%
+  # extracting the Bayes factors
+  bf_results <-
+    bf_extractor(bf.object = bf_object) %>%
     dplyr::mutate(.data = ., bf.prior = bf.prior)
 
-  # prepare the bayes factor message
+  # prepare the Bayes factor message
   if (output != "results") {
     bf_message <-
       bf_caption_maker(
@@ -556,11 +703,23 @@ bf_two_sample_ttest <- function(data,
   ))
 }
 
+#' @rdname bf_ttest
+#' @aliases bf_ttest
+#' @export
+
+bf_one_sample_ttest <- bf_ttest
+
+#' @rdname bf_ttest
+#' @aliases bf_ttest
+#' @export
+
+bf_two_sample_ttest <- bf_ttest
+
 #' @title Bayesian one-way analysis of variance.
 #' @name bf_oneway_anova
 #' @author Indrajeet Patil
 #'
-#' @importFrom BayesFactor anovaBF extractBF
+#' @importFrom BayesFactor anovaBF
 #'
 #' @inheritParams BayesFactor::anovaBF
 #' @inheritParams ggbetweenstats
@@ -569,7 +728,7 @@ bf_two_sample_ttest <- function(data,
 #' @param ... Additional arguments.
 #'
 #' @seealso \code{\link{bf_contingency_tab}}, \code{\link{bf_corr_test}},
-#' \code{\link{bf_two_sample_ttest}}
+#' \code{\link{bf_ttest}}
 #'
 #' @examples
 #'
@@ -619,7 +778,7 @@ bf_oneway_anova <- function(data,
   if (isTRUE(paired)) {
     # converting to long format and then getting it back in wide so that the
     # rowid variable can be used as the block variable
-    data <-
+    df <-
       long_to_wide_converter(
         data = data,
         x = x,
@@ -633,7 +792,7 @@ bf_oneway_anova <- function(data,
     bf_results <-
       bf_extractor(BayesFactor::anovaBF(
         value ~ key + rowid,
-        data = as.data.frame(data),
+        data = as.data.frame(df),
         whichRandom = "rowid",
         rscaleFixed = bf.prior,
         progress = FALSE,
@@ -642,17 +801,15 @@ bf_oneway_anova <- function(data,
       )) %>%
       dplyr::mutate(.data = ., bf.prior = bf.prior)
   } else {
-
     # remove NAs listwise for between-subjects design
-    data %<>%
-      tidyr::drop_na(data = .)
+    df <- tidyr::drop_na(data = data)
 
     # extracting results from bayesian test and creating a dataframe
     bf_results <-
       bf_extractor(
         BayesFactor::anovaBF(
           formula = y ~ x,
-          data = as.data.frame(data),
+          data = as.data.frame(df),
           rscaleFixed = bf.prior,
           progress = FALSE,
           ...
@@ -681,103 +838,3 @@ bf_oneway_anova <- function(data,
     bf_message
   ))
 }
-
-#' @title Bayesian one-sample *t*-test.
-#' @name bf_one_sample_ttest
-#' @author Indrajeet Patil
-#'
-#' @inheritParams BayesFactor::ttestBF
-#' @inheritParams gghistostats
-#' @inheritParams bf_corr_test
-#'
-#' @importFrom BayesFactor ttestBF extractBF
-#'
-#' @seealso \code{\link{bf_contingency_tab}}, \code{\link{bf_oneway_anova}},
-#' \code{\link{bf_two_sample_ttest}}
-#'
-#' @examples
-#'
-#' # to get caption (default)
-#' bf_one_sample_ttest(
-#'   data = iris,
-#'   x = Sepal.Length,
-#'   test.value = 5.85,
-#'   bf.prior = 0.8,
-#'   output = "caption", k = 2
-#' )
-#'
-#' # to get results dataframe
-#' bf_one_sample_ttest(
-#'   data = iris,
-#'   x = Sepal.Length,
-#'   test.value = 5.85,
-#'   bf.prior = 0.8,
-#'   output = "results"
-#' )
-#' @export
-
-# function body
-bf_one_sample_ttest <- function(data = NULL,
-                                x,
-                                test.value = 0,
-                                bf.prior = 0.707,
-                                caption = NULL,
-                                output = "null",
-                                k = 2,
-                                ...) {
-
-  # ================================= dataframe =============================
-
-  # preparing a dataframe out of provided inputs
-  if (!is.null(data)) {
-    # if dataframe is provided
-    data <-
-      dplyr::select(
-        .data = data,
-        x = !!rlang::enquo(x)
-      )
-  } else {
-    # if vectors are provided
-    data <-
-      base::cbind.data.frame(x = x)
-  }
-
-  # convert to a tibble
-  data %<>%
-    tibble::as_tibble(x = .)
-
-  # ========================= subtitle preparation ==========================
-
-  # extracting results from bayesian test and creating a dataframe
-  bf_results <-
-    bf_extractor(
-      BayesFactor::ttestBF(
-        x = data$x,
-        rscale = bf.prior,
-        mu = test.value,
-        nullInterval = NULL,
-        ...
-      )
-    ) %>%
-    dplyr::mutate(.data = ., bf.prior = bf.prior)
-
-  # prepare the bayes factor message
-  if (output != "results") {
-    bf_message <-
-      bf_caption_maker(
-        bf.df = bf_results,
-        output = output,
-        k = k,
-        caption = caption
-      )
-  }
-
-  # ============================ return ==================================
-
-  # return the text results or the dataframe with results
-  return(switch(
-    EXPR = output,
-    "results" = bf_results,
-    bf_message
-  ))
-}
