@@ -58,69 +58,61 @@ subtitle_ggscatterstats <- function(data,
   #------------------------ dataframe -------------------------------------
 
   # if dataframe is provided
-  data <-
-    dplyr::select(
-      .data = data,
-      x = !!rlang::enquo(x),
-      y = !!rlang::enquo(y)
-    ) %>%
-    stats::na.omit(.) %>%
+  data %<>%
+    dplyr::select(.data = ., x = {{ x }}, y = {{ y }}) %>%
+    tidyr::drop_na(.) %>%
     tibble::as_tibble(x = .)
 
   # the total sample size for analysis
-  sample_size <- nrow(x = data)
+  sample_size <- nrow(data)
 
   # standardize the type of statistics
   stats.type <- stats_type_switch(stats.type = type)
 
-  # Pearson's r (will also be used for Bayes tests)
-  stats_df <-
-    broomExtra::tidy(stats::cor.test(
-      formula = ~ x + y,
-      data = data,
-      method = "pearson",
-      alternative = "two.sided",
-      exact = FALSE,
-      conf.level = conf.level,
-      na.action = na.omit
-    ))
-
   #------------------------ Pearson's r -------------------------------------
 
   if (stats.type == "parametric") {
 
-    # preparing subtitle
-    subtitle <- subtitle_template(
-      no.parameters = 1L,
-      stat.title = stat.title,
-      statistic.text = quote(italic("t")),
-      statistic = stats_df$statistic[[1]],
-      parameter = stats_df$parameter[[1]],
-      p.value = stats_df$p.value[[1]],
-      effsize.text = quote(italic("r")["Pearson"]),
-      effsize.estimate = stats_df$estimate,
-      effsize.LL = stats_df$conf.low[[1]],
-      effsize.UL = stats_df$conf.high[[1]],
-      n = sample_size,
-      conf.level = conf.level,
-      k = k,
-      k.parameter = 0L
-    )
-
-    #--------------------- Spearnman's rho ---------------------------------
-  } else if (stats.type == "nonparametric") {
-
-    # note that stats::cor.test doesn't give degress of freedom; it's
-    # calculated as df = (no. of pairs - 2)
+    # Pearson's r
     stats_df <-
-      broomExtra::tidy(stats::cor.test(
-        formula = ~ x + y,
-        data = data,
-        method = "spearman",
-        alternative = "two.sided",
-        exact = FALSE,
-        na.action = na.omit
-      ))
+      broomExtra::tidy(
+        stats::cor.test(
+          formula = ~ x + y,
+          data = data,
+          method = "pearson",
+          alternative = "two.sided",
+          exact = FALSE,
+          conf.level = conf.level,
+          na.action = na.omit
+        )
+      )
+
+    # stats object already contains effect size info
+    effsize_df <- stats_df
+
+    # subtitle parameters
+    no.parameters <- 1L
+    parameter <- stats_df$parameter[[1]]
+    statistic.text <- quote(italic("t"))
+    effsize.text <- quote(italic("r")["Pearson"])
+  }
+
+  #--------------------- Spearnman's rho ---------------------------------
+  if (stats.type == "nonparametric") {
+
+    # degrees of freedom calculated as df = (no. of pairs - 2)
+    stats_df <-
+      broomExtra::tidy(
+        stats::cor.test(
+          formula = ~ x + y,
+          data = data,
+          method = "spearman",
+          alternative = "two.sided",
+          exact = FALSE,
+          na.action = na.omit
+        )
+      ) %>%
+      dplyr::mutate(.data = ., statistic = log(statistic))
 
     # getting confidence interval for rho using broom bootstrap
     effsize_df <-
@@ -130,28 +122,24 @@ subtitle_ggscatterstats <- function(data,
         use = "pairwise.complete.obs",
         conf.level = conf.level
       ) %>%
-      tibble::enframe(x = .)
+      tibble::enframe(x = .) %>%
+      tidyr::spread(data = ., key = "name", value = "value") %>%
+      dplyr::select(
+        .data = .,
+        estimate = rho,
+        conf.low = lwr.ci,
+        conf.high = upr.ci
+      )
 
-    # preparing subtitle
-    subtitle <- subtitle_template(
-      no.parameters = 0L,
-      stat.title = NULL,
-      statistic.text = quote("log"["e"](italic("S"))),
-      statistic = log(stats_df$statistic[[1]]),
-      parameter = NULL,
-      p.value = stats_df$p.value[[1]],
-      effsize.text = quote(italic(rho)["Spearman"]),
-      effsize.estimate = stats_df$estimate,
-      effsize.LL = effsize_df$value[[2]],
-      effsize.UL = effsize_df$value[[3]],
-      n = sample_size,
-      conf.level = conf.level,
-      k = k,
-      k.parameter = 0L
-    )
+    # subtitle parameters
+    no.parameters <- 0L
+    parameter <- NULL
+    statistic.text <- quote("log"["e"](italic("S")))
+    effsize.text <- quote(italic(rho)["Spearman"])
+  }
 
-    #---------------------- robust percentage bend --------------------------
-  } else if (stats.type == "robust") {
+  #---------------------- robust percentage bend --------------------------
+  if (stats.type == "robust") {
     # running robust correlation
     stats_df <-
       robcor_ci(
@@ -164,30 +152,44 @@ subtitle_ggscatterstats <- function(data,
         conf.type = conf.type
       )
 
-    # preparing subtitle
-    subtitle <- subtitle_template(
-      no.parameters = 1L,
-      stat.title = NULL,
-      statistic.text = quote(italic("t")),
-      statistic = stats_df$statistic[[1]],
-      parameter = (sample_size - 2L),
-      p.value = stats_df$p.value[[1]],
-      effsize.text = quote(italic(rho)["pb"]),
-      effsize.estimate = stats_df$estimate,
-      effsize.LL = stats_df$conf.low[[1]],
-      effsize.UL = stats_df$conf.high[[1]],
-      n = sample_size,
-      conf.level = conf.level,
-      k = k,
-      k.parameter = 0L
-    )
+    # stats object already contains effect size info
+    effsize_df <- stats_df
+
+    # subtitle parameters
+    no.parameters <- 1L
+    parameter <- sample_size - 2L
+    statistic.text <- quote(italic("t"))
+    effsize.text <- quote(italic(rho)["pb"])
 
     # message about effect size measure
     if (isTRUE(messages)) {
       effsize_ci_message(nboot = nboot, conf.level = conf.level)
     }
-    #---------------------- bayes factor -----------------------------------
-  } else if (stats.type == "bayes") {
+  }
+
+  #---------------------- preparing subtitle ---------------------------------
+  if (stats.type %in% c("parametric", "nonparametric", "robust")) {
+    # preparing subtitle
+    subtitle <- subtitle_template(
+      no.parameters = no.parameters,
+      stat.title = stat.title,
+      statistic.text = statistic.text,
+      statistic = stats_df$statistic[[1]],
+      parameter = parameter,
+      p.value = stats_df$p.value[[1]],
+      effsize.text = effsize.text,
+      effsize.estimate = effsize_df$estimate[[1]],
+      effsize.LL = effsize_df$conf.low[[1]],
+      effsize.UL = effsize_df$conf.high[[1]],
+      n = sample_size,
+      conf.level = conf.level,
+      k = k,
+      k.parameter = 0L
+    )
+  }
+
+  #---------------------- bayes factor -----------------------------------
+  if (stats.type == "bayes") {
 
     # bayes factor results
     subtitle <-
