@@ -596,39 +596,29 @@ testthat::test_that(
   }
 )
 
-# check gmm output ----------------------------------------------
+# check mlm output ----------------------------------------------
 
 testthat::test_that(
-  desc = "check gmm output",
+  desc = "check mlm output",
   code = {
     testthat::skip_on_cran()
 
-    # setup
-    set.seed(123)
-    library(gmm)
-
-    # examples come from the "gmm" package
-    ## CAPM test with GMM
-    data(Finance)
-    r <- Finance[1:300, 1:10]
-    rm <- Finance[1:300, "rm"]
-    rf <- Finance[1:300, "rf"]
-
-    z <- as.matrix(r - rf)
-    t <- nrow(z)
-    zm <- rm - rf
-    h <- matrix(zm, t, 1)
-    res <- gmm::gmm(z ~ zm, x = h)
+    # model (converting all numeric columns in data to z-scores)
+    res <- stats::lm(
+      formula = cbind(mpg, disp) ~ wt,
+      data = purrr::modify_if(.x = mtcars, .p = is.numeric, .f = scale)
+    )
 
     # plot
     df <- ggstatsplot::ggcoefstats(
       x = res,
+      exclude.intercept = FALSE,
       output = "tidy"
     )
 
     # tests
-    testthat::expect_equal(dim(df), c(10L, 12L))
-    testthat::expect_identical(as.character(df$term[[1]]), "WMK_zm")
+    testthat::expect_equal(dim(df), c(4L, 11L))
+    testthat::expect_identical(as.character(df$term[[1]]), "mpg_(Intercept)")
   }
 )
 
@@ -671,6 +661,49 @@ testthat::test_that(
   }
 )
 
+# glmmPQL object --------------------------------------------
+
+testthat::test_that(
+  desc = "ggcoefstats works with glmmPQL object",
+  code = {
+    testthat::skip_on_cran()
+
+    # setup
+    set.seed(123)
+    library(MASS)
+
+    # model
+    mod <- MASS::glmmPQL(
+      fixed = y ~ trt + I(week > 2),
+      random = ~ 1 | ID,
+      family = binomial,
+      data = bacteria,
+      verbose = FALSE
+    )
+
+    # coefficient plot
+    p <- ggstatsplot::ggcoefstats(mod, exclude.intercept = FALSE)
+
+    # build the plot
+    pb <- ggplot2::ggplot_build(p)
+
+    # checking annotations
+    testthat::expect_null(p$labels$caption, NULL)
+    testthat::expect_null(p$labels$subtitle, NULL)
+
+    # labels
+    testthat::expect_identical(
+      pb$data[[4]]$label,
+      c(
+        "list(~italic(beta)==3.41, ~italic(t)(169)==6.58, ~italic(p)<= 0.001)",
+        "list(~italic(beta)==-1.25, ~italic(t)(47)==-1.94, ~italic(p)==0.059)",
+        "list(~italic(beta)==-0.75, ~italic(t)(47)==-1.17, ~italic(p)==0.248)",
+        "list(~italic(beta)==-1.61, ~italic(t)(169)==-4.49, ~italic(p)<= 0.001)"
+      )
+    )
+  }
+)
+
 # check clm models (minimal) ----------------------------------------
 
 testthat::test_that(
@@ -849,7 +882,8 @@ testthat::test_that(
         k = 3,
         meta.analytic.effect = TRUE,
         bf.message = TRUE,
-        sample = 1000,
+        iter = 2500,
+        summarize = "int",
         messages = FALSE
       )
 
@@ -955,9 +989,9 @@ testthat::test_that(
           "0.110",
           ", CI"["95%"],
           " [",
-          "-0.175",
+          "-0.178",
           ", ",
-          "0.415",
+          "0.412",
           "]"
         )
       )),
@@ -1277,24 +1311,19 @@ testthat::test_that(
     )
 
     # mod-2
-    set.seed(123)
-    library(survival)
-    cfit <- coxph(Surv(time, status) ~ age + sex, lung)
-    mod2 <- survfit(cfit)
-
-    # mod-3
-    mod3 <- stats::aov(
+    mod2 <- stats::aov(
       formula = value ~ attribute * measure + Error(id / (attribute * measure)),
-      data = iris_long
+      data = ggstatsplot::iris_long
     )
 
     # plot
-    p <- ggstatsplot::ggcoefstats(mod3)
+    p <- ggstatsplot::ggcoefstats(mod2)
     pb <- ggplot2::ggplot_build(p)
 
     # test failures
-    testthat::expect_error(ggstatsplot::ggcoefstats(x = mod1))
-    testthat::expect_error(ggstatsplot::ggcoefstats(x = mod2))
+    testthat::expect_error(ggstatsplot::ggcoefstats(mod1))
+    testthat::expect_error(ggstatsplot::ggcoefstats(stats::acf(lh, plot = FALSE)))
     testthat::expect_null(pb$plot$labels$subtitle, NULL)
+    testthat::expect_null(pb$plot$labels$caption, NULL)
   }
 )
