@@ -131,3 +131,29 @@ testthat::test_that(
     ))
   }
 )
+
+# subtitle return --------------------------------------------------
+
+testthat::test_that(
+  desc = "subtitle return",
+  code = {
+    testthat::skip_on_cran()
+
+    # should return a list of length 3
+    ls_results <- ggstatsplot::grouped_ggbetweenstats(
+      data = iris_long,
+      x = condition,
+      y = value,
+      grouping.var = Species,
+      return = "subtitle",
+      results.subtitle = NULL,
+      messages = FALSE
+    )
+
+    # tests
+    testthat::expect_equal(length(ls_results), 3L)
+    testthat::expect_null(ls_results[[1]], NULL)
+    testthat::expect_null(ls_results[[2]], NULL)
+    testthat::expect_null(ls_results[[3]], NULL)
+  }
+)
