@@ -203,7 +203,7 @@ testthat::test_that(
           ") = ",
           "-0.425",
           ", ",
-          italic("r")["Cauchy"],
+          italic("r")["Cauchy"]^"JZS",
           " = ",
           "0.707"
         )
